@@ -100,11 +100,11 @@ openapi_schema = {
 
 def test_additional_properties_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_additional_properties_post():
     response = client.post("/foo", json={"items": {"foo": 1, "bar": 2}})
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"foo": 1, "bar": 2}
